@@ -75,14 +75,14 @@ cliff.delta.default <- function( d, f, conf.level=.95,
     if( "character" %in% class(f)){
       f = factor(f)
     }  
-    if(length(levels(f))!=2){
       if(length(unique(f))==2){
-        warning("Factor with multiple levles, using only those effectively present in data");
+        if(length(levels(f))!=2){
+        warning("Factor with multiple levels, using only those effectively present in data");
+        }
       }else{
-        stop("Factor should have only two levels");
+        stop("Factor should have exactly two effective levels");
         return;
       }
-    }
     tc = split(d,f)
     treatment = tc[[1]]
     control = tc[[2]]
@@ -95,9 +95,15 @@ cliff.delta.default <- function( d, f, conf.level=.95,
 
   if(conf.level>.9999 | conf.level<.5) stop("conf.level must be within 50% and 99.99%")
   
+  treatment = sort(treatment)
+  control = sort(control)
   n1 = length(treatment)
   n2 = length(control)
   
+  if(n1+n2<3){
+    stop("Cannot compute Cliff delta value with less than 3 values")
+  }
+  
   rescale.factor = (n1*n2-1)/(n1*n2);
 
   if(!return.dm & is.factor(treatment) & is.factor(control)){ ## use factor algorithm
@@ -121,9 +127,6 @@ cliff.delta.default <- function( d, f, conf.level=.95,
     SSR = t((dm_L-d.)^2 %*% (fc*n2)) %*% ft *n1 
   }else{ 
     ## not a factor
-    treatment = sort(treatment)
-    control = sort(control)
-    
     if(return.dm){ ## explicitly compute dominance matrix
       algorithm="Naive"
       dominance = sign(outer(treatment, control, FUN="-")) 
