@@ -100,4 +100,22 @@ test_that("double factor", {
   
   expect_equal(resf$estimate,-0.44)
   expect_equal(resv$estimate,-0.44)
+})
+
+test_that("presence of NAs", { # Issue #50
+  mtcars = mtcars
+  set.seed(12345)
+  vals = sample(1:length(mtcars$mpg), 10, replace=FALSE)
+  mtcars$mpg[vals] = NA
+  cd = cliff.delta(mtcars$mpg[which(mtcars$vs==0)],
+              mtcars$mpg[which(mtcars$vs==1)])
+  expect_equal(cd$estimate,-0.89,0.01)
+})
+
+test_that("At least 2 levels", { # Issue #46
+  expect_error(cliff.delta( 1, factor("a",c("a","b")) ),"exactly two")
+})
+
+test_that("At least 3 data points", {
+  expect_error(cliff.delta( 1:2, as.character(1:2) ))
 })
\ No newline at end of file
